# MIMiC - Large Language Models for Welsh

This package provides a few utilities and demo application for working
with LLMs tailored for the Welsh language.

For example inference usage, see the options provided by the CLI command:

```bash
accelerate launch -m mimic.inference --help
```

`techiaith-mimic` is developed and maintained by the Uned Technolegau Iaith (UTI) <https://techiaith.cymru/> team, backed by Bangor University.
<https://bangor.ac.uk/>.

Techiaith UTI is a self-funded research unit that develops technologies for the Welsh language.

To learn more about who specifically contributed to this codebase, see our contributors page.
